<?php
namespace Elementor; 
if ( ! defined( 'ABSPATH' ) ) exit; 

/**
 * Elementor Blog widget.
 *
 * Elementor widget that displays an eye-catching headlines.
 *
 * @since 1.1.0
 */

class medileaves_before_after extends Widget_Base {
	
	/**
	 * Get widget name.
	 *
	 * Retrieve button widget name.
	 *
	 * @since 1.1.0
	 * @access public
	 *
	 * @return string Widget name.
	 */

	public function get_name() {
		return __( 'medileaves_before_after', 'medileaves' );
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve button widget title.
	 *
	 * @since 1.1.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	
	public function get_title() {
		return __( 'Before After', 'medileaves' );
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the button widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * @since 2.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */

	public function get_categories() {
		return [ 'medileaves' ];
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve button widget icon.
	 *
	 * @since 1.1.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */

	public function get_icon() {
		return 'eicon-slider-push medileaves-icon';
	}

	/**
	 * Register button widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.1.0
	 * @access protected
	 */

	protected function _register_controls() {
			
		$this->start_controls_section(
			'section',
			[
				'label' => __( 'Before After', 'medileaves' ),
			]
		);

		$this->add_control(
			'before_image',
			array(
				'label'   => __( 'Before Image', 'medileaves' ),
				'type'    => Controls_Manager::MEDIA,
				'dynamic' => array(
					'active' => true,
				),
				'separator' => 'after',
				'default' => array(
					'url' => Utils::get_placeholder_image_src(),
				),
			)
		);

		$this->add_control(
			'after_image',
			array(
				'label'   => __( 'After Image', 'medileaves' ),
				'type'    => Controls_Manager::MEDIA,
				'dynamic' => array(
					'active' => true,
				),
				'default' => array(
					'url' => Utils::get_placeholder_image_src(),
				),
			)
		);

		$this->end_controls_section(); 

		$this->start_controls_section(
			'title-setting',
			[
				'label' => __( 'General Setting', 'medileaves' ),
			]
		);

		$this->add_control(
			'trigger_color',
			[
				'label' => __( 'Trigger Arrow Color', 'medileaves' ),
				'type' => Controls_Manager::COLOR,
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .image-comparison-wrapper .image-comparison__thumb .image-comparison__thumb-icon' => 'fill: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'trigger_background',
			[
				'label' => __( 'Trigger Background Color', 'medileaves' ),
				'type' => Controls_Manager::COLOR,
				'default' => '',
				'separator' => 'after',
				'selectors' => [
					'{{WRAPPER}} .image-comparison-wrapper .image-comparison__thumb' => 'background-color: {{VALUE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'Label-typography',
				'label' => __( 'Label Typography', 'medileaves' ),
				'selector' => '{{WRAPPER}} .image-comparison-wrapper .image-comparison-caption-body',
			]
		);

		$this->add_control(
			'trigger_label_color',
			[
				'label' => __( 'Label Color', 'medileaves' ),
				'type' => Controls_Manager::COLOR,
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .image-comparison-wrapper .image-comparison-caption-body' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'trigger_label_bg_color',
			[
				'label' => __( 'Label Background Color', 'medileaves' ),
				'type' => Controls_Manager::COLOR,
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .image-comparison-wrapper .image-comparison-caption-body' => 'background-color: {{VALUE}};',
				],
			]
		);

		$this->end_controls_section(); 
		


	}
	/**
	 * Render Blog widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.1.0
	 * @access protected
	 */
	
	protected function render() {
		
		$settings = $this->get_settings();
		?>
		<div class="image-comparison image-comparison-wrapper" data-component="image-comparison-slider">
			<input type="range" min="0" max="100" value="50" class="image-comparison__range" id="image-compare-range" data-image-comparison-range="" />
			<div class="image-comparison-wrapper image-comparison-overlay" data-image-comparison-overlay="">
				<div class="image-comparison__figure image-comparison__figure--overlay">
					<img src="<?php echo esc_url( $settings['before_image']['url'] ); ?>" alt="Before Image" class="image-comparison__image" />
				</div>
				<div class="image-comparison-caption image-caption-before">
					<span class="image-comparison-caption-body"><?php echo esc_html__('Before'); ?></span>
				</div>
			</div>
			
			<div class="image-comparison-slider" data-image-comparison-slider="">
				<span class="image-comparison__thumb" data-image-comparison-thumb="">
					<svg class="image-comparison__thumb-icon" xmlns="http://www.w3.org/2000/svg" width="18" height="10" viewBox="0 0 18 10" fill="currentColor">
						<path class="image-comparison__thumb-icon--left" d="M12.121 4.703V.488c0-.302.384-.454.609-.24l4.42 4.214a.33.33 0 0 1 0 .481l-4.42 4.214c-.225.215-.609.063-.609-.24V4.703z"></path>
						<path class="image-comparison__thumb-icon--right" d="M5.879 4.703V.488c0-.302-.384-.454-.609-.24L.85 4.462a.33.33 0 0 0 0 .481l4.42 4.214c.225.215.609.063.609-.24V4.703z"></path>
					</svg>
				</span>
			</div>

			<div class="image-comparison-wrapper">
				<div class="image-comparison__figure">
					<img src="<?php echo esc_url( $settings['after_image']['url'] ); ?>" alt="After Image" class="image-comparison__image" />
				</div>
				<div class="image-comparison-caption image-caption-after">
					<span class="image-comparison-caption-body"><?php echo esc_html__('After'); ?></span>
				</div>
			</div>
		</div>
	<?php
	}
}
Plugin::instance()->widgets_manager->register_widget_type( new \Elementor\medileaves_before_after() );
?>