<?php
namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Elementor Blog widget.
 *
 * Elementor widget that displays an eye-catching headlines.
 *
 * @since 1.1.0
 */

class feature_step extends Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve section title widget name.
	 *
	 * @since 1.1.0
	 * @access public
	 *
	 * @return string Widget name.
	 */

	public function get_name() {
		return __( 'feature_step', 'medileaves' );
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Feature Step widget title.
	 *
	 * @since 1.1.0
	 * @access public
	 *
	 * @return string Widget title.
	 */

	public function get_title() {
		return __( 'Feature Step', 'medileaves' );
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Feature Step widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * @since 2.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */

	public function get_categories() {
		return array( 'medileaves' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Feature Step widget icon.
	 *
	 * @since 1.1.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */

	public function get_icon() {
		return 'eicon-slider-push medileaves-icon';
	}

	/**
	 * Register Feature Step widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.1.0
	 * @access protected
	 */

	protected function _register_controls() {

		$this->start_controls_section(
			'genral-setting',
			[
				'label' => __( 'Genral Setting', 'medileaves' ),
			]
		);

		$this->add_control(
			'steps-style',
			[
				'label'      => __( 'Select Style', 'medileaves' ),
				'type'       => Controls_Manager::SELECT,
				'default'    => 'style-1',
				'options'    => [
					'style-1'          => __( 'Style 1', 'medileaves' ),
					'style-2'          => __( 'Style 2', 'medileaves' ),	
					'style-3'          => __( 'Style 3', 'medileaves' ),	
					'style-4'          => __( 'Style 4', 'medileaves' ),		
				],
			]
		);

		$this->add_control(
			'step-dotted-color',
			array(
				'label'     => __( 'Dotted Border Color', 'medileaves' ),
				'type'      => Controls_Manager::COLOR,
				'condition' => ['steps-style'=>['style-2','style-3','style-4']],
				'selectors' => array(
					'{{WRAPPER}} .features-step-new .icons-info .step-icon:before' => 'border-color: {{VALUE}};',
				),

			)
		);

		$this->add_control(
			'step_position',
			[
				'label' => __( 'Step Position', 'medileaves' ),
				'type' => Controls_Manager::CHOOSE,
				'condition' => ['steps-style'=>['style-1']],
				'options' => [
					'step-left' => [
						'title' => __( 'Start', 'medileaves' ),
						'icon' => 'eicon-h-align-left',
					],
					'step-right' => [
						'title' => __( 'End', 'medileaves' ),
						'icon' => 'eicon-h-align-right',
					],
				],
				//'default' => is_rtl() ? 'step-right' : 'step-left',
				'toggle' => false,
			]
		);

		$this->add_responsive_control(
			'step_padding',
			[
				'label' => __( 'Step Padding', 'medileaves' ),
				'type' => Controls_Manager::SLIDER,
				'condition' => ['steps-style'=>['style-2','style-3','style-4']],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 200,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .features-step-new .step-info' => 'padding-left: {{SIZE}}{{UNIT}}; padding-right: {{SIZE}}{{UNIT}};',
				],
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'step-number-setting',
			array(
				'label' => __( 'Step Number', 'medileaves' ),
			)
		);

		$this->add_control(
			'step-number',
			array(
				'label'       => __( 'Step Number', 'medileaves' ),
				'type'        => Controls_Manager::TEXT,
				'dynamic'     => array(
					'active' => true,
				),
				'label_block' => true,
				'default'     => __( '01', 'medileaves' ),
			)
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'step-number-typo',
				'label'   => __( 'Number Typography', 'medileaves' ),
				'condition' => ['steps-style'=>['style-2']],
				'selector' => '{{WRAPPER}} .features-step-new .icons-info .step-icon',
			]
		);

		$this->add_control(
			'step-number-color',
			array(
				'label'     => __( 'Number Color', 'medileaves' ),
				'type'      => Controls_Manager::COLOR,
				'condition' => ['steps-style'=>['style-1','style-3','style-4']],
				'selectors' => array(
					'{{WRAPPER}} .features-step-main .step-number' => 'color: {{VALUE}};',
				),

			)
		);

		$this->add_control(
			'step-number-bg-color',
			array(
				'label'     => __( 'Background Color', 'medileaves' ),
				'type'      => Controls_Manager::COLOR,
				'condition' => ['steps-style'=>['style-1','style-3','style-4']],
				'selectors' => array(
					'{{WRAPPER}} .features-step-main .step-number' => 'background: {{VALUE}};',
					'{{WRAPPER}} .features-step.step-style-1 .step-icon' => 'color: {{VALUE}};',
					'{{WRAPPER}} .features-step.step-style-1 .icons-info .step-number:before' => 'background: {{VALUE}};',
				),

			)
		);

		$this->add_control(
			'step-number-two-color',
			array(
				'label'     => __( 'Number Color', 'medileaves' ),
				'type'      => Controls_Manager::COLOR,
				'condition' => ['steps-style'=>['style-2']],
				'selectors' => array(
					'{{WRAPPER}} .features-step-new .icons-info .step-icon' => 'color: {{VALUE}};',
				),

			)
		);

		$this->add_control(
			'step-number-two-bg-color',
			array(
				'label'     => __( 'Background Color', 'medileaves' ),
				'type'      => Controls_Manager::COLOR,
				'condition' => ['steps-style'=>['style-2']],
				'selectors' => array(
					'{{WRAPPER}} .features-step-new .icons-info .step-icon' => 'background: {{VALUE}};',
				),

			)
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'step-icon-setting',
			array(
				'label' => __( 'Step Icon & Step Image', 'medileaves' ),
			)
		);

		$this->add_control(
			'step-icon',
			array(
				'label'            => __( 'Step Icon', 'medileaves' ),
				'type'             => Controls_Manager::ICONS,
				'fa4compatibility' => 'icon',
				'condition' => ['steps-style'=>['style-1','style-2','style-3']],
				'default'          => array(
					'value'   => 'far fa-sun',
					'library' => 'fa-solid',
				),
				'recommended'      => array(
					'fa-solid'   => array(
						'chevron-down',
						'angle-down',
						'angle-double-down',
						'caret-down',
						'caret-square-down',
					),
					'fa-regular' => array(
						'caret-square-down',
					),
				),
				'skin'             => 'inline',
				'label_block'      => false,
			)
		);

		$this->add_control(
			'step-icon-two-color',
			array(
				'label'     => __( 'Icon Color', 'medileaves' ),
				'type'      => Controls_Manager::COLOR,
				'condition' => ['steps-style'=>['style-2']],
				'selectors' => array(
					'{{WRAPPER}} .features-step-new .icons-info .step-number' => 'color: {{VALUE}};',
				),

			)
		);

		$this->add_control(
			'step-icon-two-bg-color',
			array(
				'label'     => __( 'Icon Bckground Color', 'medileaves' ),
				'type'      => Controls_Manager::COLOR,
				'condition' => ['steps-style'=>['style-2']],
				'selectors' => array(
					'{{WRAPPER}} .features-step-new .icons-info .step-number' => 'background: {{VALUE}};',
					'{{WRAPPER}} .features-step-new .icons-info .step-number:before' => 'border-color: {{VALUE}};',
				),

			)
		);

		$this->add_control(
			'step-icon-three-color',
			array(
				'label'     => __( 'Icon Color', 'medileaves' ),
				'type'      => Controls_Manager::COLOR,
				'condition' => ['steps-style'=>['style-3']],
				'selectors' => array(
					'{{WRAPPER}} .features-step-new .icons-info .step-icon' => 'color: {{VALUE}};',
				),

			)
		);

		$this->add_control(
			'step-icon-three-bg-color',
			array(
				'label'     => __( 'Icon Bckground Color', 'medileaves' ),
				'type'      => Controls_Manager::COLOR,
				'condition' => ['steps-style'=>['style-3']],
				'selectors' => array(
					'{{WRAPPER}} .features-step-new .icons-info .step-icon' => 'background: {{VALUE}};',
				),

			)
		);

		$this->add_control(
			'image',
			[
				'label' => __( 'Choose Image', 'medileaves' ),
				'type' => Controls_Manager::MEDIA,
				'dynamic' => [
					'active' => true,
				],
				'condition' => [
					'steps-style' => 'style-4',
				],
				'default' => [
					'url' => Utils::get_placeholder_image_src(),
				]
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'step-title-setting',
			array(
				'label' => __( 'Step Information', 'medileaves' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			)
		);

		$this->add_control(
			'title_tag',
			array(
				'label'   => __( 'Title Tag', 'medileaves' ),
				'type'    => Controls_Manager::SELECT,
				'default' => 'h5',
				'options' => array(
					'h2' => __( 'h2', 'medileaves' ),
					'h3' => __( 'h3', 'medileaves' ),
					'h4' => __( 'h4', 'medileaves' ),
					'h5' => __( 'h5', 'medileaves' ),
					'h6' => __( 'h6', 'medileaves' ),
				),
			)
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'step-title-typography',
				'label'   => __( 'Title Typography', 'medileaves' ),
				'selector' => '{{WRAPPER}} .features-step-main .step-info .title',
			]
		);

		$this->add_control(
			'title',
			array(
				'label'       => __( 'Step Title', 'medileaves' ),
				'type'        => Controls_Manager::TEXT,
				'dynamic'     => array(
					'active' => true,
				),
				'label_block' => true,
				'default'     => __( 'Section Title', 'medileaves' ),
			)
		);

		$this->add_control(
			'title_color',
			array(
				'label'     => __( 'Tilte Color', 'medileaves' ),
				'type'      => Controls_Manager::COLOR,
				'separator' => 'after',
				'selectors' => array(
					'{{WRAPPER}} .features-step-main .step-info .title' => 'color: {{VALUE}};',
				),

			)
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'description-typography',
				'label'   => __( 'Description Typography', 'medileaves' ),
				'selector' => '{{WRAPPER}} .features-step-main .step-info .description',
			]
		);

		$this->add_control(
			'description',
			[
				'label' => __( 'Description', 'medileaves' ),
				'type' => Controls_Manager::TEXTAREA,
				'dynamic' => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Description', 'medileaves' ),
				'default' => __( 'Lorem Ipsum is simply dummy text of the printing and typesetting industry.', 'medileaves' ),
			]
		);

		$this->add_control(
			'description_color',
			array(
				'label'     => __( 'Description Color', 'medileaves' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .features-step-main .step-info .description' => 'color: {{VALUE}};',
				),
			)
		);

		$this->add_control(
			'step-link',
			[
				'label' => __( 'Link Enable', 'medileaves' ),
				'type' => Controls_Manager::SWITCHER,
				'separator' => 'before',
				'default' => 'no',
				'yes' => __( 'yes', 'medileaves' ),
				'no' => __( 'no', 'medileaves' ),
			]
		);

		$this->add_control(
			'button-text',
			[
				'label' => __( 'Button Text', 'medileaves' ),
				'type' => Controls_Manager::TEXT,
				'dynamic' => [
					'active' => true,
				],
                'label_block' => true,
				'default' => __( 'Read More', 'medileaves' ),
				'condition' => ['step-link' => 'yes'],
			]
		);

		$this->add_control(
			'link',
			[
				'label' => __( 'Button Link', 'medileaves' ),
				'type' => Controls_Manager::URL,
				'dynamic' => [
					'active' => true,
				],
				'placeholder' => __( 'https://your-link.com', 'medileaves' ),
				'default' => [
					'url' => '#',
				],
				'condition' => ['step-link' => 'yes'],
			]
		);

		$this->add_control(
			'link_color',
			array(
				'label'     => __( 'Link Color', 'medileaves' ),
				'type'      => Controls_Manager::COLOR,
				'condition' => ['step-link' => 'yes'],
				'selectors' => array(
					'{{WRAPPER}} .features-step-main .step-info .step-link a' => 'color: {{VALUE}};',
				),
			)
		);

		$this->end_controls_section();

	}
	/**
	 * Render Blog widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.1.0
	 * @access protected
	 */

	protected function render() {

		$settings = $this->get_settings();

		$style = sprintf('%1$s',esc_html($settings['steps-style'],'medileaves'));

		$migrated = isset( $settings['__fa4_migrated']['step-icon'] );

		if ( ! isset( $settings['icon'] ) && ! Icons_Manager::is_migration_allowed() ) {
			// @todo: remove when deprecated
			// added as bc in 2.6
			// add old default
			$settings['icon']          = 'fa fa-plus';
			$settings['step_position'] = $this->get_settings( 'step_position' );
		}

		$is_new   = empty( $settings['icon'] ) && Icons_Manager::is_migration_allowed();
		$has_icon = ( ! $is_new || ! empty( $settings['step-icon']['value'] ) );

		if ( ! empty( $settings['link']['url'] ) ) {
			$this->add_link_attributes( 'button', $settings['link'] );
		}

		if ( ! empty( $settings['image']['url'] ) ) 
		{
			$this->add_render_attribute( 'image', 'src', $settings['image']['url'] );
			$this->add_render_attribute( 'image', 'srcset', $settings['image']['url'] );
			$this->add_render_attribute( 'image', 'alt', Control_Media::get_image_alt( $settings['image'] ) );
			$this->add_render_attribute( 'image', 'title', Control_Media::get_image_title( $settings['image'] ) );
			$media_html = Group_Control_Image_Size::get_attachment_image_html( $settings, 'thumbnail', 'image' );
		}

		$url = $settings['link']['url'];
		$this->add_render_attribute( 'step-class', 'href', esc_url($url) );

		if ( $settings['steps-style'] === 'style-1' ) {
			?>
			<div class="features-step-main">
				<div class="features-step step-style-1 <?php echo esc_attr( $settings['step_position'] ); ?>">
					<div class="step-inner">
						<div class="icons-info">
							<span class="step-number"><?php echo __($settings['step-number'],'medileaves'); ?></span>
							<div class="step-icon"><?php Icons_Manager::render_icon( $settings['step-icon'] ); ?></div>
						</div>
						<div class="step-info">
							<<?php echo $settings['title_tag'];  ?> class="title"><?php echo __($settings['title'],'medileaves'); ?></<?php echo $settings['title_tag'];  ?>>
							<div class="description"><?php echo sprintf('%1$s',esc_html($settings['description'],'medileaves'));?></div>
							<?php if($settings['step-link'] == 'yes') { ?>
								<div class="step-link"><a <?php echo $this->get_render_attribute_string( 'step-class' ) ?>><span><?php echo sprintf('%1$s',esc_html($settings['button-text'],'medileaves'));?></span><i class="ti-arrow-right"></i></a></div>
							<?php } ?>
						</div>
					</div>
				</div>
			</div>
			<?php
		}
		if ( $settings['steps-style'] === 'style-2' ) {
			?>
			<div class="features-step-main">
				<div class="features-step-new <?php echo esc_attr($align);?>">
					<div class="step-inner">
						<div class="icons-info">
							<span class="step-number"><?php Icons_Manager::render_icon( $settings['step-icon'] ); ?></span>
							<div class="step-icon"><span><?php echo __($settings['step-number'],'medileaves'); ?></span></div>
						</div>
						<div class="step-info">
							<<?php echo $settings['title_tag'];  ?> class="title"><?php echo __($settings['title'],'medileaves'); ?></<?php echo $settings['title_tag'];  ?>>
							<div class="description"><?php echo sprintf('%1$s',esc_html($settings['description'],'medileaves'));?></div>
							<?php if($settings['step-link'] == 'yes') { ?>
								<div class="step-link"><a <?php echo $this->get_render_attribute_string( 'step-class' ) ?>><span><?php echo sprintf('%1$s',esc_html($settings['button-text'],'medileaves'));?></span><i class="ti-arrow-right"></i></a></div>
							<?php } ?>
						</div>
					</div>
				</div>
			</div>
			<?php
		}
		if ( $settings['steps-style'] === 'style-3' ) {
			?>
			<div class="features-step-main">
				<div class="features-step-new <?php echo esc_attr($align);?>">
					<div class="step-inner">
						<div class="icons-info">
							<span class="step-number"><?php echo __($settings['step-number'],'medileaves'); ?></span>
							<div class="step-icon"><?php Icons_Manager::render_icon( $settings['step-icon'] ); ?></div>
						</div>
						<div class="step-info">
							<<?php echo $settings['title_tag'];  ?> class="title"><?php echo __($settings['title'],'medileaves'); ?></<?php echo $settings['title_tag'];  ?>>
							<div class="description"><?php echo sprintf('%1$s',esc_html($settings['description'],'medileaves'));?></div>
							<?php if($settings['step-link'] == 'yes') { ?>
								<div class="step-link"><a <?php echo $this->get_render_attribute_string( 'step-class' ) ?>><span><?php echo sprintf('%1$s',esc_html($settings['button-text'],'medileaves'));?></span><i class="ti-arrow-right"></i></a></div>
							<?php } ?>
						</div>
					</div>
				</div>
			</div>
			<?php
		}
		if ( $settings['steps-style'] === 'style-4' ) {
			?>
			<div class="features-step-main">
				<div class="features-step-new style-image">
					<div class="step-inner">
						<div class="icons-info">
							<span class="step-number"><?php echo __($settings['step-number'],'medileaves'); ?></span>
							<div class="step-icon"><?php echo $media_html; ?></div>
						</div>
						<div class="step-info">
							<<?php echo $settings['title_tag'];  ?> class="title"><?php echo __($settings['title'],'medileaves'); ?></<?php echo $settings['title_tag'];  ?>>
							<div class="description"><?php echo sprintf('%1$s',esc_html($settings['description'],'medileaves'));?></div>
							<?php if($settings['step-link'] == 'yes') { ?>
									<div class="step-link"><a <?php echo $this->get_render_attribute_string( 'step-class' ) ?>><span><?php echo sprintf('%1$s',esc_html($settings['button-text'],'medileaves'));?></span><i class="ti-arrow-right"></i></a></div>
								<?php } ?>
						</div>
					</div>
				</div>
			</div>
			<?php
		}
	}
}
Plugin::instance()->widgets_manager->register_widget_type( new \Elementor\feature_step() );
?>
