<?php
namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Elementor Blog widget.
 *
 * Elementor widget that displays an eye-catching headlines.
 *
 * @since 1.1.0
 */

class image_hotspot extends Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Image Hotspot widget name.
	 *
	 * @since 1.1.0
	 * @access public
	 *
	 * @return string Widget name.
	 */

	public function get_name() {
		return __( 'image_hotspot', 'medileaves' );
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Image Hotspot widget title.
	 *
	 * @since 1.1.0
	 * @access public
	 *
	 * @return string Widget title.
	 */

	public function get_title() {
		return __( 'Image Hotspot', 'medileaves' );
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Image Hotspot widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * @since 2.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */

	public function get_categories() {
		return array( 'medileaves' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Image Hotspot widget icon.
	 *
	 * @since 1.1.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */

	public function get_icon() {
		return 'eicon-slider-push medileaves-icon';
	}

	/**
	 * Register Image Hotspot widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.1.0
	 * @access protected
	 */

	protected function _register_controls() {

		$this->start_controls_section(
			'sub_title-setting',
			array(
				'label' => __( 'Main Image', 'medileaves' ),
			)
		);

		$this->add_control(
			'image',
			array(
				'label'   => __( 'Main Image', 'medileaves' ),
				'type'    => Controls_Manager::MEDIA,
				'dynamic' => array(
					'active' => true,
				),
				'default' => array(
					'url' => Utils::get_placeholder_image_src(),
				),
			)
		);

		$this->add_control(
			'pointer-style',
			[
				'label'      => __( 'Pointer Style', 'medileaves' ),
				'type'       => Controls_Manager::SELECT,
				'default'    => 'style-1',
				'options'    => [
					'style-1'          => __( 'Style 1', 'medileaves' ),
					'style-2'          => __( 'Style 2', 'medileaves' ),			
				],
			]
		);

		$this->add_control(
			'pointer-trigger',
			[
				'label'      => __( 'Pointer Trigger', 'medileaves' ),
				'type'       => Controls_Manager::SELECT,
				'default'    => 'trigger-hover',
				'options'    => [
					'trigger-hover'          => __( 'Hover', 'medileaves' ),
					'trigger-click'          => __( 'Click', 'medileaves' ),				
				],
			]
		);

		$this->end_controls_section(); 

		$this->start_controls_section(
			'image-hotspot1',
			[
				'label' => __( 'Image Hotspot', 'medileaves' ),
			]
		);

		$this->add_control(
			'hotspot_trigger_color',
			[
				'label' => __( 'Trigger Color', 'medileaves' ),
				'type' => Controls_Manager::COLOR,
				'default' => '',
				'separator' => 'after',
				'selectors' => [
					'{{WRAPPER}} .image-hotspot-wrapper.style-1 .hotspot-trigger' => 'border-color: {{VALUE}};',
					'{{WRAPPER}} .image-hotspot-wrapper.style-1 .hotspot-trigger span' => 'background-color: {{VALUE}};',
					'{{WRAPPER}} .image-hotspot-wrapper.style-2 .hotspot-trigger span' => 'background-color: {{VALUE}};',
					'{{WRAPPER}} .image-hotspot-wrapper.style-2 .hotspot-trigger span:before' => 'background-color: {{VALUE}};',
					'{{WRAPPER}} .image-hotspot-wrapper.style-2 .hotspot-trigger span:after' => 'background-color: {{VALUE}};',
				],
			]
		);

		$repeater = new Repeater();

		$repeater->add_control(
			'title',
			[
				'label' => __( 'Hotspot Title', 'medileaves' ),
				'type' => Controls_Manager::TEXT,
				'dynamic' => [
					'active' => true,
				],
                'label_block' => true,
                'default' => __( 'Hotspot Title', 'medileaves' ),
			]
		);

		$repeater->add_control(
			'description',
			[
				'label' => __( 'Hotspot Description', 'medileaves' ),
				'type' => Controls_Manager::TEXTAREA,
				'dynamic' => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Description', 'medileaves' ),
				'default' => __( 'Lorem Ipsum is simply dummy text of the printing and typesetting industry.', 'medileaves' ),
			]
		);
		
		$repeater->add_responsive_control(
			'horizontal_size',
			array(
				'label'     => __( 'Horizontal Alignment', 'medileaves' ),
				'type'      => Controls_Manager::SLIDER,
				'default' => [
					'size' => '0',
				],
				'range' => [
					'px' => [
						'min' => -2000,
						'max' => 2000,
						'step' => 1,
					],
					'%' => [
						'min' => -100,
						'max' => 100,
					],
					'vw' => [
						'min' => -100,
						'max' => 100,
					],
					'vh' => [
						'min' => -100,
						'max' => 100,
					],
				],
				'size_units' => [ 'px', '%', 'vw', 'vh' ],
				'selectors' => array(
					'{{WRAPPER}} .image-hotspot-wrapper .image-hotspot-content .image-hotspot{{CURRENT_ITEM}}' => 'left: {{SIZE}}{{UNIT}};',
				),
			)
		);

		$repeater->add_responsive_control(
			'vertical_size',
			array(
				'label'     => __( 'Vertical Alignment', 'medileaves' ),
				'type'      => Controls_Manager::SLIDER,
				'default' => [
					'size' => '0',
				],
				'range' => [
					'px' => [
						'min' => -2000,
						'max' => 2000,
						'step' => 1,
					],
					'%' => [
						'min' => -100,
						'max' => 100,
					],
					'vw' => [
						'min' => -100,
						'max' => 100,
					],
					'vh' => [
						'min' => -100,
						'max' => 100,
					],
				],
				'size_units' => [ 'px', '%', 'vw', 'vh' ],
				'selectors' => array(
					'{{WRAPPER}} .image-hotspot-wrapper .image-hotspot-content .image-hotspot{{CURRENT_ITEM}}' => 'top: {{SIZE}}{{UNIT}};',
				),
			)
		);

		$repeater->add_control(
			'item-direction',
			[
				'label' => __( 'Item Direction', 'medileaves' ),
				'type' => Controls_Manager::CHOOSE,
				'default' => 'content-top',
				'options' => [
					'content-left' => [
						'title' => __( 'Left', 'medileaves' ),
						'icon' => 'eicon-h-align-left',
					],
					'content-top' => [
						'title' => __( 'Top', 'medileaves' ),
						'icon' => 'eicon-v-align-top',
					],
					'content-bottom' => [
						'title' => __( 'Bottom', 'medileaves' ),
						'icon' => 'eicon-v-align-bottom',
					],										
					'content-right' => [
						'title' => __( 'Right', 'medileaves' ),
						'icon' => 'eicon-h-align-right',
					],
				],
			]
		);

		$repeater->add_responsive_control(
			'hotspot-hide-tablet',
			[
				'label' => __( 'Hide Tablet', 'medileaves' ),
				'type' => Controls_Manager::SWITCHER,
				'default' => 'no',
				'yes' => __( 'yes', 'medileaves' ),
				'no' => __( 'no', 'medileaves' ),
			]
		);

		$repeater->add_responsive_control(
			'hotspot-hide-mobile',
			[
				'label' => __( 'Hide Mobile', 'medileaves' ),
				'type' => Controls_Manager::SWITCHER,
				'default' => 'no',
				'yes' => __( 'yes', 'medileaves' ),
				'no' => __( 'no', 'medileaves' ),
			]
		);

		$this->add_control(
			'tabs',
			array(
				'label'       => __( 'Tabs Items', 'medileaves' ),
				'type'        => Controls_Manager::REPEATER,
				'fields'      => $repeater->get_controls(),
				'range' => [
					'min' => 0,
					'max' => 5,
				],
			)
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'style-info',
			[
				'label' => __( 'Item Setting', 'medileaves' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_responsive_control(
			'button_padding',
			[
				'label' => __( 'Padding', 'medileaves' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'{{WRAPPER}} .image-hotspot-wrapper .image-hotspot-content .hotspot-content' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_control(
			'border_radius',
			[
				'label' => __( 'Border Radius', 'medileaves' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'separator'  => 'after',
				'selectors' => [
					'{{WRAPPER}} .image-hotspot-wrapper .image-hotspot-content .hotspot-content' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_group_control(
		Group_Control_Typography::get_type(),
			[
				'name' => 'hotspot-title-typography',
				'label' => __( 'Title Typography', 'medileaves' ),
				'selector' => '{{WRAPPER}} .image-hotspot-wrapper .image-hotspot-content .hotspot-content .hotspot-title',
			]
		);

		$this->add_group_control(
		Group_Control_Typography::get_type(),
			[
				'name' => 'hotspot-text-typography',
				'label' => __( 'Text Typography', 'medileaves' ),
				'selector' => '{{WRAPPER}} .image-hotspot-wrapper .image-hotspot-content .hotspot-content .hotspot-description',
			]
		);

		$this->add_control(
			'hotspot_content_bg',
			[
				'label' => __( 'Hotspot BG Color', 'medileaves' ),
				'type' => Controls_Manager::COLOR,
				'separator'  => 'before',
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .image-hotspot-wrapper .image-hotspot-content .hotspot-content' => 'background-color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'hotspot_content_title_color',
			[
				'label' => __( 'Hotspot Title Color', 'medileaves' ),
				'type' => Controls_Manager::COLOR,
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .image-hotspot-wrapper .image-hotspot-content .hotspot-content .hotspot-title' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'hotspot_content_text_color',
			[
				'label' => __( 'Hotspot Text Color', 'medileaves' ),
				'type' => Controls_Manager::COLOR,
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .image-hotspot-wrapper .image-hotspot-content .hotspot-content .hotspot-description' => 'color: {{VALUE}};',
				],
			]
		);


		$this->end_controls_section(); 


	}
	/**
	 * Render Blog widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.1.0
	 * @access protected
	 */

	protected function render() {

		$settings = $this->get_settings();

		$tabs = $this->get_settings_for_display( 'tabs' );
		
		if ( ! empty( $settings['image']['url'] ) ) {
			$this->add_render_attribute( 'image', 'src', $settings['image']['url'] );
			$this->add_render_attribute( 'image', 'srcset', $settings['image']['url'] );
			$this->add_render_attribute( 'image', 'alt', Control_Media::get_image_alt( $settings['image'] ) );
			$this->add_render_attribute( 'image', 'title', Control_Media::get_image_title( $settings['image'] ) );
			$image = Group_Control_Image_Size::get_attachment_image_html( $settings, 'thumbnail', 'image' );
		}

		$pointer_style = sprintf('%1$s',esc_html($settings['pointer-style'],'medileaves'));
		$pointer_trigger = sprintf('%1$s',esc_html($settings['pointer-trigger'],'medileaves'));

		?>
		<div class="image-hotspot-wrapper <?php echo $pointer_style; ?> <?php echo $pointer_trigger; ?>">
			<div class="image-hotspot-inner">
				<?php echo $image; ?>
				<div class="image-hotspot-content">
					<?php
					$i = 0;
					foreach ( $tabs as $index => $item ) {
						
						$link_key = 'link_' . $index;

						$this->add_render_attribute( $link_key, 'class', [
							'image-hotspot elementor-repeater-item-' . $item['_id'],  $item['vertical-align'],
						] );

						if($item['hotspot-hide-tablet'] == 'yes'){ $this->add_render_attribute( $link_key, 'class', 'hotspot-hide-tablet' ); }
						if($item['hotspot-hide-mobile'] == 'yes'){ $this->add_render_attribute( $link_key, 'class', 'hotspot-hide-mobile' ); }
					?>
					<div <?php echo $this->get_render_attribute_string( $link_key ); ?>>
						<div class="hotspot-trigger"><span></span></div>
						<div class="hotspot-content <?php echo sprintf('%1$s',esc_html($item['item-direction'],'medileaves')); ?>">
							<?php if($item['title']) { ?>
								<h3 class="hotspot-title"><?php echo sprintf('%1$s',esc_html($item['title'],'medileaves')); ?></h3>
							<?php } if($item['description']) { ?>
							<div class="hotspot-description"><?php echo sprintf('%1$s',esc_html($item['description'],'medileaves'));?></div>
							<?php } ?>
						</div>
					</div>
					<?php } ?>
				</div>
			</div>
		</div>
		<?php
	}
}
Plugin::instance()->widgets_manager->register_widget_type( new \Elementor\image_hotspot() );
?>
