<?php
namespace Elementor; 
if ( ! defined( 'ABSPATH' ) ) exit; 

/**
 * Elementor Blog widget.
 *
 * Elementor widget that displays an eye-catching headlines.
 *
 * @since 1.1.0
 */

class medileaves_image_parallax extends Widget_Base {
	
	/**
	 * Get widget name.
	 *
	 * Retrieve button widget name.
	 *
	 * @since 1.1.0
	 * @access public
	 *
	 * @return string Widget name.
	 */

	public function get_name() {
		return __( 'medileaves_image_parallax', 'medileaves' );
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve button widget title.
	 *
	 * @since 1.1.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	
	public function get_title() {
		return __( 'Image Parallax', 'medileaves' );
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the button widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * @since 2.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */

	public function get_categories() {
		return [ 'medileaves' ];
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve button widget icon.
	 *
	 * @since 1.1.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */

	public function get_icon() {
		return 'eicon-slider-push medileaves-icon';
	}

	/**
	 * Register button widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.1.0
	 * @access protected
	 */

	protected function _register_controls() {
			
		$this->start_controls_section(
			'section',
			[
				'label' => __( 'Parallax Image', 'medileaves' ),
			]
		);

		$this->add_responsive_control(
			'parallax_image_width',
			[
				'label' => esc_html__( 'Image Width', 'medileaves' ),
				'type' => Controls_Manager::SLIDER,
				'default' => [
					'unit' => '%',
				],
				'tablet_default' => [
					'unit' => '%',
				],
				'mobile_default' => [
					'unit' => '%',
				],
				'size_units' => [ '%', 'px', 'vw' ],
				'range' => [
					'%' => [
						'min' => 1,
						'max' => 100,
					],
					'px' => [
						'min' => 1,
						'max' => 1000,
					],
					'vw' => [
						'min' => 1,
						'max' => 100,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .image-parallax-wrapper .parallax-image' => 'width: {{SIZE}}{{UNIT}};',
				],
			]
		);

		$this->add_control(
			'parallax_image',
			array(
				'label'   => __( 'Parallax Image', 'medileaves' ),
				'type'    => Controls_Manager::MEDIA,
				'dynamic' => array(
					'active' => true,
				),
				'default' => array(
					'url' => Utils::get_placeholder_image_src(),
				),
			)
		);

		$this->add_control(
			'parallax_image_effect',
			[
				'label' => __( 'Image Parallax Effect', 'medileaves' ),
				'type' => Controls_Manager::SWITCHER,
				'default' => 'no',
				'yes' => __( 'yes', 'medileaves' ),
				'no' => __( 'no', 'medileaves' ),
			]
		);

		$this->add_control(
			'parallax_image_rotate',
			[
				'label' => __( 'Image Infinite Rotate', 'medileaves' ),
				'type' => Controls_Manager::SWITCHER,
				'default' => 'no',
				'separator'   => 'after',
				'yes' => __( 'yes', 'medileaves' ),
				'no' => __( 'no', 'medileaves' ),
			]
		);

		$this->add_control(
			'parallax_border_type',
			[
				'label'      => __( 'Border Type', 'medileaves' ),
				'type'       => Controls_Manager::SELECT,
				'default'    => 'none',
				'options'    => [
					'none'          => __( 'None', 'medileaves' ),
					'solid'         => __( 'Solid', 'medileaves' ),	
					'double'        => __( 'Double', 'medileaves' ),
					'dotted'        => __( 'Dotted', 'medileaves' ),
					'dashed'        => __( 'Dashed', 'medileaves' ),
					'groove'        => __( 'Groove', 'medileaves' ),	
				],
				'selectors' => [
					'{{WRAPPER}} .image-parallax-wrapper .parallax-image img' => 'border-style: {{VALUE}};',
				],
			]
		);

		$this->add_responsive_control(
			'parallax_border_width',
			[
				'label' => __( 'Border Width', 'medileaves' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'condition' => [
					'parallax_border_type'=>['solid','double','dotted','dashed','groove']
				],
				'selectors' => [
					'{{WRAPPER}} .image-parallax-wrapper .parallax-image img' => 'border-width: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_control(
			'parallax_border_color',
			array(
				'label'     => __( 'Border Color', 'medileaves' ),
				'type'      => Controls_Manager::COLOR,
				'default'   => '',
				'condition' => [
					'parallax_border_type'=>['solid','double','dotted','dashed','groove']
				],
				'selectors' => array(
					'{{WRAPPER}} .image-parallax-wrapper .parallax-image img' => 'border-color: {{VALUE}};',
				),
			)
		);

		$this->add_responsive_control(
			'parallax_border_radius',
			[
				'label' => __( 'Border Radius', 'medileaves' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'{{WRAPPER}} .image-parallax-wrapper .parallax-image img' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			array(
				'label'     => __( 'Box Shadow', 'medileaves' ),
				'name'      => 'image_box_shadow',
				'exclude'   => array(
					'box_shadow_position',
				),
				'selector'  => '{{WRAPPER}} .image-parallax-wrapper .parallax-image img',
			)
		);

		$this->end_controls_section(); 

	}
	/**
	 * Render Blog widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.1.0
	 * @access protected
	 */
	
	protected function render() {
		
		$settings = $this->get_settings();
		$this->add_render_attribute('infinite-rotate', 'class', 'image-parallax-wrapper');
		$this->add_render_attribute('parallax-effect', 'class', 'parallax-image');
		if ( $settings['parallax_image_rotate'] == 'yes' ) {
			$this->add_render_attribute( 'infinite-rotate', 'class', 'text-infinite-rotate' );
		}
		if ( $settings['parallax_image_effect'] == 'yes' ) {
			$this->add_render_attribute( 'parallax-effect', 'class', 'parallax-enable' );
		}
		?>
		<div <?php echo $this->get_render_attribute_string( 'infinite-rotate' ); ?>>
        	<div <?php echo $this->get_render_attribute_string( 'parallax-effect' ); ?>>
        		<img src="<?php echo esc_url( $settings['parallax_image']['url'] ); ?>" alt="Parallax Image" class="img-parallax" />
        	</div>
      	</div>
	<?php
	}
}
Plugin::instance()->widgets_manager->register_widget_type( new \Elementor\medileaves_image_parallax() );
?>