<?php
namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Elementor Blog widget.
 *
 * Elementor widget that displays an eye-catching headlines.
 *
 * @since 1.1.0
 */

class marquee_slider extends Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve client logo widget name.
	 *
	 * @since 1.1.0
	 * @access public
	 *
	 * @return string Widget name.
	 */

	public function get_name() {
		return __( 'marquee_slider', 'medileaves' );
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve client logo widget title.
	 *
	 * @since 1.1.0
	 * @access public
	 *
	 * @return string Widget title.
	 */

	public function get_title() {
		return __( 'Marquee Slider', 'medileaves' );
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the client logo widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * @since 2.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */

	public function get_categories() {
		return array( 'medileaves' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve client logo widget icon.
	 *
	 * @since 1.1.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */

	public function get_icon() {
		return 'eicon-slider-push medileaves-icon';
	}

	/**
	 * Register client logo widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.1.0
	 * @access protected
	 */

	protected function _register_controls() {

		$this->start_controls_section(
			'client-items',
			array(
				'label' => __( 'Genral Setting', 'medileaves' ),
			)
		);

		$this->add_control(
			'marquee-slide-bg',
			[
				'label' => __( 'Marquee Slide BG', 'medileaves' ),
				'type' => Controls_Manager::SWITCHER,
				'default' => 'no',
				'yes' => __( 'yes', 'medileaves' ),
				'no' => __( 'no', 'medileaves' ),
			]
        );

        $this->add_control(
			'marquee-paused',
			[
				'label' => __( 'Marquee Hover Paused', 'medileaves' ),
				'type' => Controls_Manager::SWITCHER,
				'default' => 'no',
				'yes' => __( 'yes', 'medileaves' ),
				'no' => __( 'no', 'medileaves' ),
			]
        );

        $this->add_responsive_control(
			'slider-position',
			[
				'label' => __( 'Marquee Slide Position', 'medileaves' ),
				'type' => Controls_Manager::CHOOSE,
				'options' => [
					'slide-position-left' => [
						'title' => __( 'Left', 'medileaves' ),
						'icon' => 'eicon-h-align-left',
					],
					'slide-position-right' => [
						'title' => __( 'Right', 'medileaves' ),
						'icon' => 'eicon-h-align-right',
					]
				]
			]
		);

		$this->add_responsive_control(
			'marquee_slide_space',
			[
				'label' => __( 'Marquee Slide Space', 'medileaves' ),
				'type' => Controls_Manager::SLIDER,
				'separator' => 'before',
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 100,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .marquee-slider .marquee-slider-inner' => 'padding: {{SIZE}}{{UNIT}} 0;',
				],
			]
		);

		$this->add_responsive_control(
			'marquee_item_gap',
			[
				'label' => __( 'Marquee Title Space', 'medileaves' ),
				'type' => Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 200,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .marquee-slider .marquee-slide' => 'gap: {{SIZE}}{{UNIT}};',
				],
			]
		);

		$repeater = new Repeater();
		
		$repeater->add_control(
			'tab-title',
			[
				'label' => __( 'Title', 'medileaves' ),
				'type' => Controls_Manager::TEXT,
				'default' => __( 'Tab Title', 'medileaves' ),
				'placeholder' => __( 'Tab Title', 'medileaves' ),
				'label_block' => true,
			]
        );

		$this->end_controls_section(); 

			$this->start_controls_section(
				'marquee-items',
				[
					'label' => __( 'Marquee Items', 'medileaves' ),
				]
			);

				$this->add_control(
					'tabs',
					array(
						'label'  => __( 'Slider Items', 'medileaves' ),
						'type'   => Controls_Manager::REPEATER,
						'label_block' => true,
						'fields' => $repeater->get_controls(),
					)
				);

			$this->end_controls_section();

		$this->end_controls_section();

		$this->start_controls_section(
			'Marquee_color',
			array(
				'label' => __( 'Marquee Color', 'medileaves' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			)
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'title-typography',
				'label' => __( 'Title Typography', 'medileaves' ),
				'selector' => '{{WRAPPER}} .marquee-slider .marquee-item .title',
			]
		);

		$this->add_control(
			'marquee_text_color',
			array(
				'label'     => __( 'Marquee Title Color', 'medileaves' ),
				'type'      => Controls_Manager::COLOR,
				'default'   => '',
				'selectors' => array(
					'{{WRAPPER}} .marquee-slider .marquee-item .title' => 'color: {{VALUE}};',
				),
			)
		);

		$this->add_control(
			'marquee_slide_bg',
			array(
				'label'     => __( 'Marquee Slide BG', 'medileaves' ),
				'type'      => Controls_Manager::COLOR,
				'condition' => [
					'marquee-slide-bg'=>['yes']
				],
				'default'   => '',
				'selectors' => array(
					'{{WRAPPER}} .marquee-slider.slide-bg-on .marquee-slider-inner:before' => 'background: {{VALUE}};',
				),
			)
		);

		$this->add_group_control(
			Group_Control_Background::get_type(),
			array(
				'name'      => 'marquee_background_color',
				'label'     => __( 'Background Color', 'medileaves' ),
				'types'     => array( 'gradient' ),
				'selector'  => '{{WRAPPER}} .marquee-slider .marquee-slider-inner',
			)
		);


		$this->end_controls_section();

	}
	/**
	 * Render Blog widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.1.0
	 * @access protected
	 */

	protected function render() {

		$settings = $this->get_settings();
		$tabs     = $this->get_settings_for_display( 'tabs' );

		$this->add_render_attribute( 'marquee-slider', 'class', 'marquee-slider' );

		$this->add_render_attribute( 'marquee-slider', 'class', $settings['slider-position'] );

		if($settings['marquee-slide-bg'] == 'yes') {
			$this->add_render_attribute( 'marquee-slider', 'class', 'slide-bg-on' ); 
		}

		if($settings['marquee-paused'] == 'yes') {
			$this->add_render_attribute( 'marquee-slider', 'class', 'marquee-hover-paused' ); 
		}

		//$align = $settings['align'];
		?>

		<div <?php echo $this->get_render_attribute_string( 'marquee-slider' ); ?>>
			<div class="marquee-slider-inner">
				<div class="marquee-slide">
					<?php
					foreach ( $tabs as $index => $item ) {
					?>
					<div class="marquee-item"><h4 class="title"><?php echo esc_html($item['tab-title'],'medileaves'); ?></h4></div>
					<?php } ?>
				</div>
				<div class="marquee-slide">
					<?php
					foreach ( $tabs as $index => $item ) {
					?>
					<div class="marquee-item"><h4 class="title"><?php echo esc_html($item['tab-title'],'medileaves'); ?></h4></div>
					<?php } ?>
				</div>
			</div>   
		</div>
		<?php
	}
}
Plugin::instance()->widgets_manager->register_widget_type( new \Elementor\marquee_slider() );
?>
