<?php
/**
 * Widget API: Elementer product category Widget
 *
 * @package medileaves
 * @subpackage Widgets
 * @since 1.0.0
 */

namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Elementor product category widget.
 *
 * Elementor widget that displays a product category with the ability to control every
 * aspect of the product category design.
 *
 * @since 1.0.0
 */
class Widget_medileaves_Product_Cat extends Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve product category widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return __( 'Product Category', 'medileaves' );
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve product category widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Product Category', 'medileaves' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve product category widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_categories() {
		return array( 'medileaves' );
	}



	/**
	 * Get widget icon.
	 *
	 * Retrieve heading widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-slider-push medileaves-icon';
	}


	/**
	 * Register product category widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	// @codingStandardsIgnoreStart
	protected function _register_controls() {

		// @codingStandardsIgnoreEnd
		$this->start_controls_section(
			'product-category',
			array(
				'label' => __( 'Product Category', 'medileaves' ),
			)
		);

		$this->add_control(
			'product-category-style',
			[
				'label'      => __( 'Select Style', 'medileaves' ),
				'type'       => Controls_Manager::SELECT,
				'default'    => 'product-cat-style-1',
				'options'    => [
					'product-cat-style-1'       => __( 'Style 1', 'medileaves' ),
					'product-cat-style-2'        => __( 'Style 2', 'medileaves' ),
					'product-cat-style-3'          => __( 'Style 3', 'medileaves' ),		
				],
			]
		);

		$this->add_control(
			'desk-number',
			array(
				'label'       => __( 'Desktop view', 'medileaves' ),
				'type'        => Controls_Manager::TEXT,
				'dynamic'     => array(
					'active' => true,
				),
				'label_block' => true,
				'default'     => '3',
			)
		);
		$this->add_control(
			'lap-number',
			array(
				'label'       => __( 'Laptop view', 'medileaves' ),
				'type'        => Controls_Manager::TEXT,
				'dynamic'     => array(
					'active' => true,
				),
				'label_block' => true,
				'default'     => '3',
			)
		);
		$this->add_control(
			'tab-number',
			array(
				'label'       => __( 'Tablet view', 'medileaves' ),
				'type'        => Controls_Manager::TEXT,
				'dynamic'     => array(
					'active' => true,
				),
				'label_block' => true,
				'default'     => '2',
			)

		);
		$this->add_control(
			'mob-number',
			array(
				'label'       => __( 'Mobile view', 'medileaves' ),
				'type'        => Controls_Manager::TEXT,
				'dynamic'     => array(
					'active' => true,
				),
				'label_block' => true,
				'default'     => '1',
			)
		);
		$this->add_control(
			'autoplay',
			array(
				'label'   => __( 'Autoplay', 'medileaves' ),
				'type'    => Controls_Manager::SELECT,
				'default' => 'true',
				'options' => array(
					'true'  => __( 'True', 'medileaves' ),
					'false' => __( 'False', 'medileaves' ),
				),
			)
		);
		$this->add_control(
			'loop',
			array(
				'label'   => __( 'Loop', 'medileaves' ),
				'type'    => Controls_Manager::SELECT,
				'default' => 'true',
				'options' => array(
					'true'  => __( 'True', 'medileaves' ),
					'false' => __( 'False', 'medileaves' ),
				),
			)
		);
		$this->add_control(
			'dots',
			array(
				'label'   => __( 'Dots', 'medileaves' ),
				'type'    => Controls_Manager::SELECT,
				'default' => 'true',
				'options' => array(
					'true'  => __( 'True', 'medileaves' ),
					'false' => __( 'False', 'medileaves' ),
				),
			)
		);
		$this->add_control(
			'arrow',
			array(
				'label'   => __( 'Arrow', 'medileaves' ),
				'type'    => Controls_Manager::SELECT,
				'default' => 'true',
				'options' => array(
					'true'  => __( 'True', 'medileaves' ),
					'false' => __( 'False', 'medileaves' ),
				),
			)
		);
		$this->add_responsive_control(
			'margin',
			array(
				'label'   => __( 'Margin', 'medileaves' ),
				'type'    => Controls_Manager::SLIDER,
				'default' => array(
					'size' => 30,
				),
			)
		);

		$this->end_controls_section();

	}

	/**
	 * Render product category widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings();

		$this->add_render_attribute( 'product-category', 'class', 'products-category-wrapper swiper-container' );
		$this->add_render_attribute( 'product-category', 'data-dots', $settings['dots'] );
		$this->add_render_attribute( 'product-category', 'data-nav', $settings['arrow'] );
		$this->add_render_attribute( 'product-category', 'data-items', $settings['desk-number'] );
		$this->add_render_attribute( 'product-category', 'data-lg-items', $settings['lap-number'] );
		$this->add_render_attribute( 'product-category', 'data-md-items', $settings['tab-number'] );
		$this->add_render_attribute( 'product-category', 'data-sm-items', $settings['mob-number'] );
		$this->add_render_attribute( 'product-category', 'data-xs-items', $settings['mob-number'] );
		$this->add_render_attribute( 'product-category', 'data-autoplay', $settings['autoplay'] );
		$this->add_render_attribute( 'product-category', 'data-loop', $settings['loop'] );
		$this->add_render_attribute( 'product-category', 'data-margin', $settings['margin']['size'] );

		$this->add_render_attribute( 'product-category-class', 'class', $settings['product-category-style'] );

		$query_args = array(
			'taxonomy'   => 'product_cat',
			'pad_counts' => true,
		);

		$categories = get_terms( $query_args );
		?>
		<div <?php echo $this->get_render_attribute_string( 'product-category-class' ) ?>>
			<div <?php echo $this->get_render_attribute_string( 'product-category' ); ?>>

					<div class="swiper-wrapper">
						<?php foreach ( $categories as $category ) :
							
							$cat_thumb_id = get_woocommerce_term_meta( $category->term_id, 'thumbnail_id', true );
							$shop_catalog_img = wp_get_attachment_image_src( $cat_thumb_id, 'shop_catalog' );
							$term_link = get_term_link( $category, 'product_cat' );
						?>
							<div class="swiper-slide">							
								<div class="items">
									<div class="products-category-main">
										<div class="category-image">
											<a href="<?php echo $term_link; ?>"><img src="<?php echo $shop_catalog_img[0]; ?>" alt="<?php echo $category->name; ?>" /></a>
										</div>
										<div class="category-info">
											<h3 class="category-title">
												<?php
												echo esc_html($category->name);
												if ( $category->count > 0 ) echo apply_filters( 'woocommerce_subcategory_count_html', ' ', $category );
												?>
											</h3>
											<a href="<?php echo esc_url( get_term_link( $category->slug, 'product_cat' ) ); ?>" class="category-number">
												<?php //if ( ! $hide_product_count ): ?>
													<span class="cat-number"><?php echo sprintf( _n( '%s Item', '%s Items', $category->count, 'medileaves' ), $category->count ); ?></span>
												<?php //endif; ?>
											</a>
										</div>
										<a href="<?php echo esc_url( get_term_link( $category->slug, 'product_cat' ) ); ?>" class="category-title-link"></a>
									</div>
								</div>

							</div>
						<?php endforeach; ?>
					</div>
				<div class="swiper-pagination"></div>
				<div class="swiper-button-next"><i class="fas fa-chevron-right"></i></div>
				<div class="swiper-button-prev"><i class="fas fa-chevron-left"></i></div>
			</div>
		</div>
		<?php
		if ( Plugin::$instance->editor->is_edit_mode() ) :
			?>
			<script>
				jQuery('.swiper-container' ).each(function () {
					var swiper = new Swiper( jQuery( this ), {
					slidesPerView:  ((jQuery(this).attr('data-items')) ? jQuery(this).attr('data-items') : 4),
					spaceBetween:   ((jQuery(this).attr('data-space')) ? jQuery(this).data('space') : 15),
					autoplay:       ((jQuery(this).attr('data-autoplay')) ? jQuery(this).data('autoplay') : false),
					loop:           ((jQuery(this).attr('data-loop')) ? jQuery(this).data('loop') : false),
					navigation: {
						nextEl: '.swiper-next',
						prevEl: '.swiper-prev',
					},
					pagination: {
						el: '.swiper-pagination',
						clickable: true,
					},
					breakpoints: {
						1200: {slidesPerView: ((jQuery(this).attr('data-items')) ? jQuery(this).attr('data-items') : 4),},
						992:  {slidesPerView: ((jQuery(this).attr('data-lg-items')) ? jQuery(this).attr('data-lg-items') : 3),},
						768:  {slidesPerView: ((jQuery(this).attr('data-md-items')) ? jQuery(this).attr('data-md-items') : 2),},
						480:  {slidesPerView: ((jQuery(this).attr('data-sm-items')) ? jQuery(this).attr('data-sm-items') : 1),},
						0:  {slidesPerView: ((jQuery(this).attr('data-xs-items')) ? jQuery(this).attr('data-xs-items') : 1),}
					}
					});
				});
			</script>
		<?php endif;
	}
}

Plugin::instance()->widgets_manager->register_widget_type( new \Elementor\Widget_medileaves_Product_Cat() );
