<?php
/**
 * Widget API: Elementer product Listing Widget
 *
 * @package medileaves
 * @subpackage Widgets
 * @since 1.0.0
 */

namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Elementor product Listing widget.
 *
 * Elementor widget that displays a product Listing with the ability to control every
 * aspect of the product Listing design.
 *
 * @since 1.0.0
 */
class Widget_medileaves_Product_Listing extends Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve product Listing widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return __( 'Product Listing', 'medileaves' );
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve product Listing widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Product Listing', 'medileaves' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve product Listing widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_categories() {
		return array( 'medileaves' );
	}



	/**
	 * Get widget icon.
	 *
	 * Retrieve heading widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-slider-push medileaves-icon';
	}


	/**
	 * Register product Listing widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	// @codingStandardsIgnoreStart
	protected function _register_controls() {
		$this->start_controls_section(
			'section_blog',
			[
				'label' => __( 'Product Listing Grid', 'medileaves' ),
				
			]
		);

		$this->add_control(
			'product_type',
			[
				'label'      => __( 'Select Product', 'medileaves' ),
				'type'       => Controls_Manager::SELECT,
				'default'    => 'all',
				'options'    => [		
					'all' => __( 'All Product', 'medileaves' ),					
					'featured_products' => __( 'Feature Product', 'medileaves' ),
					'sale_products' => __( 'On Sale Product', 'medileaves' ),
					'best_selling_products' => __( 'Best Selling Product', 'medileaves' ),
					'top_rated_products'    => __( 'Top Rated Product', 'medileaves' ),
					'recent_products'          => __( 'Recent Products', 'medileaves' ),
				],
			]
		);

		$this->add_control(
			'product-style',
			array(
				'label'   => __( 'Select Style', 'medileaves' ),
				'type'    => Controls_Manager::SELECT,
				'default' => 'slider',
				'options' => array(
					'slider' => __( 'Slider', 'medileaves' ),
					'grid'   => __( 'Gride', 'medileaves' ),
				),
			)
		);
		
        $this->end_controls_section();

		$this->start_controls_section(
			'grid_setting',
			array(
				'label' => __( 'Grid Setting', 'medileaves' ),
				'condition' => array( 'product-style' => array( 'grid' ) ),
			)
		);

		$this->add_control(
			'total-count',
			array(
				'label'       => __( 'Total Count', 'medileaves' ),
				'type'        => Controls_Manager::TEXT,
				'dynamic'     => array(
					'active' => true,
				),
				'condition' => array( 'product-style' => array( 'grid' ) ),
				'label_block' => true,
				'default'     => '4',
			)
        );

		$this->add_control(
			'grid-desk',
			array(
				'label'     => __( 'Desktop view', 'medileaves' ),
				'type'      => Controls_Manager::SELECT,
				'default'   => 'desk-grid-4',
				'condition' => array( 'product-style' => array( 'grid' ) ),
				'options'   => array(
					'desk-grid-2' => __( '2 Column', 'medileaves' ),
					'desk-grid-3' => __( '3 Column', 'medileaves' ),
					'desk-grid-4' => __( '4 Column', 'medileaves' ),
					'desk-grid-5' => __( '5 Column', 'medileaves' ),
				),
			)
        );
        
        $this->add_control(
			'grid-lap',
			array(
				'label'     => __( 'Laptop view', 'medileaves' ),
				'type'      => Controls_Manager::SELECT,
				'default'   => 'lap-grid-3',
				'condition' => array( 'product-style' => array( 'grid' ) ),
				'options'   => array(
					'lap-grid-2' => __( '2 Column', 'medileaves' ),
					'lap-grid-3' => __( '3 Column', 'medileaves' ),
					'lap-grid-4' => __( '4 Column', 'medileaves' ),
				),
			)
        );

        $this->add_control(
			'grid-tab',
			array(
				'label'     => __( 'Tablet view', 'medileaves' ),
				'type'      => Controls_Manager::SELECT,
				'default'   => 'tab-grid-3',
				'condition' => array( 'product-style' => array( 'grid' ) ),
				'options'   => array(
					'tab-grid-2' => __( '2 Column', 'medileaves' ),
					'tab-grid-3' => __( '3 Column', 'medileaves' ),
					'tab-grid-4' => __( '4 Column', 'medileaves' ),
				),
			)
        );
        
        $this->add_control(
			'grid-mobile',
			array(
				'label'     => __( 'Mobile view', 'medileaves' ),
				'type'      => Controls_Manager::SELECT,
				'default'   => 'mob-grid-2',
				'condition' => array( 'product-style' => array( 'grid' ) ),
				'options'   => array(
                    'mob-grid-1' => __( '1 Column', 'medileaves' ),
                    'mob-grid-2' => __( '2 Column', 'medileaves' ),
					'mob-grid-3' => __( '3 Column', 'medileaves' ),
				),
			)
        );
        
        $this->add_control(
			'grid-mobile-portal',
			array(
				'label'     => __( 'Mobile Portal view', 'medileaves' ),
				'type'      => Controls_Manager::SELECT,
				'default'   => 'mobpor-grid-1',
				'condition' => array( 'product-style' => array( 'grid' ) ),
				'options'   => array(
                    'mobpor-grid-1' => __( '1 Column', 'medileaves' ),
                    'mobpor-grid-2' => __( '2 Column', 'medileaves' ),
				),
			)
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'slider_setting',
			array(
				'label' => __( 'Slider Setting', 'medileaves' ),
				'condition' => array( 'product-style' => array( 'slider' ) ),
			)
		);

		$this->add_control(
			'slider-desk',
			array(
				'label'       => __( 'Desktop view', 'medileaves' ),
				'condition' => array( 'product-style' => array( 'slider' ) ),
				'type'        => Controls_Manager::TEXT,
				'dynamic'     => array(
					'active' => true,
				),
				'label_block' => true,
				'default'     => '5',
			)
		);

		$this->add_control(
			'slider-laptop',
			array(
				'label'       => __( 'Laptop view', 'medileaves' ),
				'type'        => Controls_Manager::TEXT,
				'condition' => array( 'product-style' => array( 'slider' ) ),
				'dynamic'     => array(
					'active' => true,
				),
				'label_block' => true,
				'default'     => '4',
			)
		);

		$this->add_control(
			'slider-tab',
			array(
				'label'       => __( 'Tablet view', 'medileaves' ),
				'type'        => Controls_Manager::TEXT,
				'condition' => array( 'product-style' => array( 'slider' ) ),
				'dynamic'     => array(
					'active' => true,
				),
				'label_block' => true,
				'default'     => '3',
			)
		);

		$this->add_control(
			'slider-mobile',
			array(
				'label'       => __( 'Mobile view', 'medileaves' ),
				'type'        => Controls_Manager::TEXT,
				'condition' => array( 'product-style' => array( 'slider' ) ),
				'dynamic'     => array(
					'active' => true,
				),
				'label_block' => true,
				'default'     => '2',
			)
		);

		$this->add_control(
			'slider-mobile-portal',
			array(
				'label'       => __( 'Mobile Portal View', 'medileaves' ),
				'type'        => Controls_Manager::TEXT,
				'condition' => array( 'product-style' => array( 'slider' ) ),
				'dynamic'     => array(
					'active' => true,
				),
				'label_block' => true,
				'default'     => '1',
			)
		);

		$this->add_control(
			'autoplay',
			array(
				'label'   => __( 'Autoplay', 'medileaves' ),
				'type'    => Controls_Manager::SELECT,
				'condition' => array( 'product-style' => array( 'slider' ) ),
				'default' => 'true',
				'options' => array(
					'true'  => __( 'True', 'medileaves' ),
					'false' => __( 'False', 'medileaves' ),

				),
			)
		);

		$this->add_control(
			'loop',
			array(
				'label'   => __( 'Loop', 'medileaves' ),
				'type'    => Controls_Manager::SELECT,
				'condition' => array( 'product-style' => array( 'slider' ) ),
				'default' => 'true',
				'options' => array(
					'true'  => __( 'True', 'medileaves' ),
					'false' => __( 'False', 'medileaves' ),

				),
			)
		);

		$this->add_control(
			'slider-dots',
			array(
				'label'   => __( 'Dots', 'medileaves' ),
				'type'    => Controls_Manager::SELECT,
				'condition' => array( 'product-style' => array( 'slider' ) ),
				'default' => 'true',
				'options' => array(
					'true'  => __( 'True', 'medileaves' ),
					'false' => __( 'False', 'medileaves' ),

				),
			)
		);

		$this->add_control(
			'slider-arrow',
			array(
				'label'   => __( 'Arrow', 'medileaves' ),
				'type'    => Controls_Manager::SELECT,
				'condition' => array( 'product-style' => array( 'slider' ) ),
				'default' => 'true',
				'options' => array(
					'true'  => __( 'True', 'medileaves' ),
					'false' => __( 'False', 'medileaves' ),

				),
			)
		);

		$this->add_control(
			'arrow-style',
			array(
				'label'     => __( 'Arrow Style', 'medileaves' ),
				'type'      => Controls_Manager::SELECT,
				'condition' => array( 'product-style' => array( 'slider' ) ),
				'condition' => array(
					'slider-arrow' => array( 'true' ),
				),
				'default'   => 'arrow-default',
				'options'   => array(
					'arrow-default' => __( 'Default', 'medileaves' ),
					'arrow-style2'  => __( 'Style 2', 'medileaves' ),
					'arrow-style3'  => __( 'Style 3', 'medileaves' ),
				),
			)
		);

		$this->add_responsive_control(
			'data-space',
			array(
				'label' => __( 'Margin', 'elementor' ),
				'condition' => array( 'product-style' => array( 'slider' ) ),
				'type'  => Controls_Manager::SLIDER,
			)
		);

		$this->end_controls_section();
		
	}

	/**
	 * Render product tab widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function render() {
		$settings     = $this->get_settings();

		if ( $settings['product-style'] === 'slider' ) {
			$this->add_render_attribute( 'pro-cat', 'data-items', $settings['slider-desk'] );
			$this->add_render_attribute( 'pro-cat', 'data-lg-items', $settings['slider-laptop'] );
			$this->add_render_attribute( 'pro-cat', 'data-md-items', $settings['slider-tab'] );
			$this->add_render_attribute( 'pro-cat', 'data-sm-items', $settings['slider-mobile'] );
			$this->add_render_attribute( 'pro-cat', 'data-xs-items', $settings['slider-mobile-portal'] );
			$this->add_render_attribute( 'pro-cat', 'data-space', $settings['data-space']['size'] );
			$this->add_render_attribute( 'pro-cat', 'data-arrow', $settings['slider-arrow'] );
			$this->add_render_attribute( 'pro-cat', 'data-bullets', $settings['slider-dots'] );
			$this->add_render_attribute( 'pro-cat', 'data-autoplay', $settings['autoplay'] );
			$this->add_render_attribute( 'pro-cat', 'data-loop', $settings['loop'] );
		}
		if ( $settings['product-style'] === 'grid' ) {
			$desk_grid_opt    = sprintf( '%1$s', esc_html( $settings['grid-desk'], 'medileaves' ) );
			$lap_grid_opt    = sprintf( '%1$s', esc_html( $settings['grid-lap'], 'medileaves' ) );
			$tab_grid_opt    = sprintf( '%1$s', esc_html( $settings['grid-tab'], 'medileaves' ) );
			$mob_grid_opt    = sprintf( '%1$s', esc_html( $settings['grid-mobile'], 'medileaves' ) );
			$mobport_grid_opt = sprintf( '%1$s', esc_html( $settings['grid-mobile-portal'], 'medileaves' ) );
		}
				
		if (!function_exists('wc_get_products')) {
		return;
		}

		$paged = (get_query_var('paged')) ? absint(get_query_var('paged')) : 1;

		
		$nav_content  = '';
		$product_html = '';

			$args = array(
				'status'   => 'publish',
				'limit'    => 100,
				'post_per_page' => -1,      
				'post_type' => 'product'
		  
			 );
			
			
			if ($settings['product_type'] == 'featured_products') {
				$args['featured'] = true;
			} else if ($settings['product_type'] == 'top_rated_products') {
				$args['meta_key'] = '_wc_average_rating';
				$args['orderby']  = 'rating';      
				$args['orderby']  = 'meta_value_num';
				$args['order'] = 'DESC';
			} else if ($settings['product_type'] == 'best_selling_products') {
			   // echo $settings['product_type'];
				$args['meta_key'] = 'total_sales';
				$args['orderby']  = 'meta_value_num';
				$args['order'] = 'DESC';
			} else if ($settings['product_type'] == 'recent_products') {
				$args['orderby']  = 'date';
				$args['order'] = 'DESC';
			} else{
		  
			}

			$products = wc_get_products($args);

			if ($products) {

				foreach ($products as $product_id) {

					$product     = wc_get_product($product_id);

					$avg_rate    = $product->get_average_rating();
					$rating      = '';
					for ($i = 1; $i <= $avg_rate; $i++) {
						$rating .= '<i class="fa fa-star e-star"></i>';
					}

					$newness_days = 1;
					$new_flag = 0;
					$created = strtotime( $product->get_date_created() );
					if ( ( time() - ( 60 * 60 * 24 * $newness_days ) ) < $created ) {
						$new_flag = 1;
					}
					$percentage = 0;
					if($product->is_on_sale()) {
						if( $product->is_type('variable')){
						$percentages = array();
				
						// Get all variation prices
						$prices = $product->get_variation_prices();
				
						// Loop through variation prices
						foreach( $prices['price'] as $sale_var_key => $price ){
							// Only on sale variations
							if( $prices['regular_price'][$sale_var_key] !== $price ){
								// Calculate and set in the array the percentage for each variation on sale
								$percentages[] = round(100 - ($prices['sale_price'][$sale_var_key] / $prices['regular_price'][$sale_var_key] * 100));
							}
						}
						$percentage = max($percentages) . '%';
						}
						else {
							$regular_price = (float) $product->get_regular_price();
							$sale_price    = (float) $product->get_sale_price();
							if($regular_price > 0 ) {
								$percentage    = round(100 - ($sale_price / $regular_price * 100)) . '%';
							}
						}
					}
					else {
						if($settings['product_type'] == 'sale_products') {
							continue;
						}
					}

					$date = get_post_meta( $product->get_id(),'my_coutdown',true );

					$product_html .= '<div class="swiper-slide">';
						$product_html .= '<div class="product-wrapper-main">';
							$product_html .= '<div class="product-block-inner">';
								$product_html .= '<div class="product-thumbnail">';							
											
											$product_html .= '<div class="product-main-image">';
												$product_html .= '<a href="' . get_permalink($product->get_id()) . '">';
												$image = wp_get_attachment_image_src( get_post_thumbnail_id( $product->get_id() ), 'single-post-thumbnail' );
												$product_html .= '<img class="img1" src="' .  $image[0] . '" data-id="' . $product->get_id() . '">';

												// Get gallery images IDs
												if( $gallery_image_ids = get_post_meta( $product->get_id(), '_product_image_gallery', true ) ) :
												// Convert a coma separated string of Ids to an array of Ids
												$gallery_image_ids = explode(',', $gallery_image_ids);

												// Display the first image (optional)

												$product_html .= '<img class="hover_image" src="' . wp_get_attachment_image_url( reset($gallery_image_ids), 'single-post-thumbnail') . '" data-id="' . $product->get_id() . '">';

												endif;
												$product_html .= '</a>';
											$product_html .= '</div>';

											$product_html .= '<div class="product-lable">';
												if($percentage) {
												$product_html .= '<span class="lable-discount">-'.$percentage.'</span>';
												}
												if($new_flag == 1) {
												$product_html .= '<span class="lable-text">' . esc_html__( 'New', 'medileaves' ) . '</span>';
												}
											$product_html .= '</div>';

											// get product_tags of the current product
											$current_tags = get_the_terms( $product->get_id(), 'product_tag' );
											//only start if we have some tags
											if ( $current_tags && ! is_wp_error( $current_tags ) ) { 

												//create a list to hold our tags
												$product_html .= '<div class="product-lable">';

												//for each tag we create a list item
												foreach ($current_tags as $tag) { 

													$tag_title = $tag->name; // tag name

													$product_html .= '<span class="lable-text">'.$tag_title.'</span>';
												}

												$product_html .= '</div>';
											}
											$product_html .='<div class="product-action-icon">
																<a href="'.$product->add_to_cart_url().'" class="ajax_add_to_cart add_to_cart_button" data-product_id="'.$product->get_id().'"><i class="fa fa-shopping-bag"></i>Add to Cart</a>
																[yith_wcwl_add_to_wishlist product_id="'.$product->get_id().'"]
															</div>';
														if($date) {
															$product_html .= '<div class="product-countdown" data-countdown="' . esc_attr($date) .'"></div>';
														}
								$product_html .= '</div>';

											

								$product_html .='<div class="product-info">
													<h3 class="product-title"><a href="' . get_permalink($product->get_id()) . '">' . esc_html($product->get_name()) . '</a></h3>
													<div class="price-detail">
														<div class="star-rating">
															' . $rating . '
														</div>
														<span class="price">' . $product->get_price_html() . '</span>
													</div>';
								$product_html .='</div>';
							$product_html .='</div>';
						$product_html .='</div>';
					$product_html .='</div>';
					
				}
				wp_reset_postdata();

			}
			if ( $settings['product-style'] === 'grid' ) {
				$nav_content .= '' . $product_html . '';
			}
			if ( $settings['product-style'] === 'slider' ) {
				$nav_content .= '<div class="products-items">
								<div class="products-tab-slider swiper-container">
									<div class="swiper-wrapper">
										' . $product_html . '
									</div>	
									<div class="swiper-pagination"></div>
									<div class="swiper-button-next"><i class="fas fa-chevron-right"></i></div>
									<div class="swiper-button-prev"><i class="fas fa-chevron-left"></i></div>								
								</div>								
							</div>';

				$nav_content .= '';
			}
			$product_html = '';

		?>
		<?php if ( $settings['product-style'] === 'grid' ) { ?>
			<div class="products-items">
				<div class="products-grid <?php echo $desk_grid_opt; ?> <?php echo $lap_grid_opt; ?> <?php echo $tab_grid_opt; ?> <?php echo $mob_grid_opt; ?> <?php echo $mobport_grid_opt; ?>">
					<?php echo $nav_content; ?>
				</div>
			</div>
		<?php
		}
		if ( $settings['product-style'] === 'slider' ) { ?>
			<div class="products-tab-main">
				<div <?php echo $this->get_render_attribute_string( 'pro-cat' ); ?>>
					<div class="tab products-tabs">
						<div class="tab-content products-slider">
							<?php echo $nav_content; ?>
						</div>
					</div>
				</div>
			</div>
			<?php
		}
		if ( Plugin::$instance->editor->is_edit_mode() ) :
			?>
		<script>
			jQuery('.swiper-container' ).each(function () {
				var swiper = new Swiper( jQuery( this ), {
				slidesPerView:  ((jQuery(this).attr('data-items')) ? jQuery(this).attr('data-items') : 4),
				spaceBetween:   ((jQuery(this).attr('data-space')) ? jQuery(this).data('space') : 15),
				autoplay:       ((jQuery(this).attr('data-autoplay')) ? jQuery(this).data('autoplay') : false),
				loop:           ((jQuery(this).attr('data-loop')) ? jQuery(this).data('loop') : false),
				navigation: {
					nextEl: '.swiper-button-next',
					prevEl: '.swiper-button-prev',
				},
				pagination: {
					el: '.swiper-pagination',
					clickable: true,
				},
				breakpoints: {
					1200: {slidesPerView: ((jQuery(this).attr('data-items')) ? jQuery(this).attr('data-items') : 4),},
					992:  {slidesPerView: ((jQuery(this).attr('data-lg-items')) ? jQuery(this).attr('data-lg-items') : 3),},
					768:  {slidesPerView: ((jQuery(this).attr('data-md-items')) ? jQuery(this).attr('data-md-items') : 2),},
					480:  {slidesPerView: ((jQuery(this).attr('data-sm-items')) ? jQuery(this).attr('data-sm-items') : 1),},
					0:  {slidesPerView: ((jQuery(this).attr('data-xs-items')) ? jQuery(this).attr('data-xs-items') : 1),}
				}
				});
			});
		</script>
		<?php endif;
	}
}

Plugin::instance()->widgets_manager->register_widget_type( new \Elementor\Widget_medileaves_Product_Listing() );
