<?php
/**
 * Header Options
 *
 * @package medileaves Core
 * @subpackage Core
 * @since 1.1.0
 * @version 1.1.0
 */

Redux::setSection(
	'medileaves_redux',
	array(
		'title'            => esc_html__( 'Site Header', 'medileaves' ),
		'id'               => 'header-editor',
		'icon'             => 'el el-arrow-up',
		'customizer_width' => '500px',
	)
);

Redux::setSection(
	'medileaves_redux',
	array(
		'title'      => esc_html__( 'Topbar', 'medileaves' ),
		'id'         => 'header-opt',
		'subsection' => true,
		'desc'       => esc_html__( '', 'medileaves' ),
		'fields'     => array(

			array(
				'id'    => 'info_site_header_top',
				'type'  => 'info',
				'style' => 'custom',
				'color' => sanitize_hex_color( '#2b2b2b' ),
				'title' => __( 'Layout Options', 'medileaves' ),
				'desc'  => __( 'This Section Contain Option For Your Site Layout.', 'medileaves' ),
			),

			array(
				'id'     => 'section-general',
				'type'   => 'section',
				'indent' => true,
			),

			array(
				'id'       => 'header_top',
				'type'     => 'button_set',
				'title'    => esc_html__( 'Display Topbar', 'medileaves' ),
				'subtitle' => esc_html__( 'Turn on to display the Email and Phone, Login and Button on header menu.', 'medileaves' ),
				'options'  => array(
					'on'  => esc_html__( 'On', 'medileaves' ),
					'off' => esc_html__( 'Off', 'medileaves' ),
				),
				'default'  => esc_html__( 'off', 'medileaves' ),
			),

			array(
				'id'       => 'header_topbar_mobile',
				'type'     => 'button_set',
				'title'    => __( 'Topbar Mobile', 'medileaves' ),
				'required' => array( 'header_top', '=', 'on' ),
				'compiler' => 'true',
				'options'  => array(
					'topbar-mobile-on' => 'On',
					'topbar-mobile-off' => 'Off',
				),
				'default'  => 'topbar-mobile-off',
			),

			array(
				'id'       => 'header-top-blocks',
				'type'     => 'sorter',
				'title'    => 'Topbar Elements',
				'desc'     => 'Organize how you want the layout to appear on the homepage',
				'required' => array( 'header_top', '=', 'on' ),
				'compiler' => 'true',
				'options'  => array(
					'Left'               => array(
						'email' => 'Email',
						'phone' => 'Phone',
					),
					'Right'              => array(
						'text'         => 'Text',
						'social-media' => 'Social Media',
					),
					'Available Elements' => array(
						'topbar-menu' => 'Topbar Menu',
					),
				),
			),

			array(
				'id'          => 'top_bg_color',
				'type'        => 'color',
				'title'       => esc_html__( 'Topbar Background Color', 'medileaves' ),
				'required'    => array( 'header_top', '=', 'on' ),
				'default'     => '#ffffff',
				'mode'        => 'background',
				'transparent' => false,
			),

			array(
				'id'          => 'top_text_color',
				'type'        => 'color',
				'title'       => esc_html__( 'Topbar Text/Link Color', 'medileaves' ),
				'required'    => array( 'header_top', '=', 'on' ),
				'default'     => '#757887',
				'mode'        => 'background',
				'transparent' => false,
			),

			array(
				'id'          => 'top_link_color',
				'type'        => 'color',
				'title'       => esc_html__( 'Topbar Link Hover Color', 'medileaves' ),
				'required'    => array( 'header_top', '=', 'on' ),
				'default'     => '#1f64ff',
				'mode'        => 'background',
				'transparent' => false,
			),

			array(
				'id'          => 'top_icon_color',
				'type'        => 'color',
				'title'       => esc_html__( 'Topbar Icon Color', 'medileaves' ),
				'required'    => array( 'header_top', '=', 'on' ),
				'default'     => '#1f64ff',
				'mode'        => 'background',
				'transparent' => false,
			),


		),

	)
);

Redux::setSection(
	'medileaves_redux',
	array(
		'title'            => esc_html__( 'Header Main', 'medileaves' ),
		'id'               => 'header-main',
		'subsection'       => true,
		'customizer_width' => '400px',
		'desc'             => esc_html__( 'This section contains options for header.', 'medileaves' ),
		'fields'           => array(

			array(
				'id'       => 'header_type',
				'type'     => 'image_select',
				'title'    => esc_html__( 'Header Layout', 'medileaves' ),
				'subtitle' => esc_html__( 'Select the design variation that you want to use for site header.', 'medileaves' ),
				'options'  => array(
					'1' => array(
						'alt' => 'Style1',
						'img' => get_template_directory_uri() . '/assets/images/theme-option/site-header/header-1.jpg',
					),
					'2' => array(
						'alt' => 'Style2',
						'img' => get_template_directory_uri() . '/assets/images/theme-option/site-header/header-2.jpg',
					),
					'3' => array(
						'alt' => 'Style3',
						'img' => get_template_directory_uri() . '/assets/images/theme-option/site-header/header-3.jpg',
					),
				),
				'default'  => '1',
			),

			array(
				'id'       => 'header_setting',
				'type'     => 'button_set',
				'title'    => __( 'Header Setting', 'medileaves' ),
				'required' => array(
					array( 'header_type', '!=', '2' ),
				),
				'subtitle' => __( 'Select the Header Setting want to use with site header.', 'medileaves' ),
				'options'  => array(
					'header-default' => 'Default',
					'header-transparnt' => 'Transparnt',
					'header-transparnt-light' => 'Transparnt Light',
				),
				'default'  => 'header-default',
			),

			array(
				'id'       => 'header_trigger',
				'type'     => 'button_set',
				'title'    => __( 'Header Sidemenu Trigger', 'medileaves' ),
				'required' => array( 'header_type', '=', '3' ),
				'subtitle' => __( 'Select Sidemenu Trigger Background Color.', 'medileaves' ),
				'options'  => array(
					'sidemenu-trigger-primary' => 'Primary',
					'sidemenu-trigger-primary-second' => 'Primary Second',
					'sidemenu-trigger-dark' => 'Dark',
					'sidemenu-trigger-custom' => 'Custom',
				),
				'default'  => 'sidemenu-trigger-primary',
			),

			array(
				'id'       => 'header-width',
				'type'     => 'button_set',
				'title'    => __( 'Header Width', 'medileaves' ),
				'required' => array( 'header_type', '=', '1' ),
				'subtitle' => __( 'Select the Header Container Size want to use with site header.', 'medileaves' ),
				'options'  => array(
					'container-width' => 'Container',
					'full-width' => 'Full Width',
				),
				'default'  => 'container-width',
			),

			array(
				'id'          => 'header_trigger_bg_color',
				'type'        => 'color',
				'title'       => esc_html__( 'Trigger Background Color', 'medileaves' ),
				'required' => array(
					array( 'header_type', '=', '3' ),
					array( 'header_trigger', '=', 'sidemenu-trigger-custom' ),
				),
				'default'     => '#1F64FF',
				'mode'        => 'background',
				'transparent' => false,
			),

			array(
				'id'          => 'header_trigger_icon_color',
				'type'        => 'color',
				'title'       => esc_html__( 'Trigger Icon Color', 'medileaves' ),
				'required' => array(
					array( 'header_type', '=', '3' ),
					array( 'header_trigger', '=', 'sidemenu-trigger-custom' ),
				),
				'default'     => '#ffffff',
				'mode'        => 'background',
				'transparent' => false,
			),

			// Header Background Color

			array(
				'id'     => 'header-color-section',
				'type'   => 'section',
				'title'  => esc_html__( 'Header Color Setting', 'medileaves' ),
				'indent' => true,
			),

			array(
				'id'       => 'header-color',
				'type'     => 'button_set',
				'title'    => __( 'Header Color Option', 'medileaves' ),
				'subtitle' => __( 'Set Header Custom Color Setting.', 'medileaves' ),
				'options'  => array(
					'header-color-default' => 'Default',
					'header-color-custom' => 'Custom',
				),
				'default'  => 'header-color-default',
			),

			array(
				'id'          => 'header_bg_color',
				'type'        => 'color',
				'title'       => esc_html__( 'Header Background Color', 'medileaves' ),
				'required'       => array( 'header-color', '=', 'header-color-custom' ),
				'default'     => '#ffffff',
				'mode'        => 'background',
				'transparent' => false,
			),
			
			array(
				'id'          => 'header_menu_bg_color',
				'type'        => 'color',
				'title'       => esc_html__( 'Menu Background Color', 'medileaves' ),
				//'required'       => array( 'header-color', '=', 'header-color-custom' ),
				'required' => array(
					array( 'header_type', '=', '2' ),
					array( 'header-color', '=', 'header-color-custom' ),
				),
				'default'     => '#1F64FF',
				'mode'        => 'background',
				'transparent' => false,
			),

			array(
				'id'          => 'header_text_color',
				'type'        => 'color',
				'title'       => esc_html__( 'Header Text/Link Color', 'medileaves' ),
				'required'       => array( 'header-color', '=', 'header-color-custom' ),
				'default'     => '#757887',
				'mode'        => 'background',
				'transparent' => false,
			),

			array(
				'id'          => 'header_link_color',
				'type'        => 'color',
				'title'       => esc_html__( 'Header Link Hover Color', 'medileaves' ),
				'required'       => array( 'header-color', '=', 'header-color-custom' ),
				'default'     => '#1f64ff',
				'mode'        => 'background',
				'transparent' => false,
			),

			// Header Infobox Color Option
			array(
				'id'     => 'header-info-color-section',
				'type'   => 'section',
				'title'  => esc_html__( 'Header Info Color', 'medileaves' ),
				'required' => array(
					array( 'header_type', '!=', '1' ),
					array( 'header-color', '=', 'header-color-custom' ),
				),
				'indent' => true,
			),

			array(
				'id'          => 'header_info_icon_color',
				'type'        => 'color',
				'title'       => esc_html__( 'Info Icon Color', 'medileaves' ),
				'required' => array(
					array( 'header_type', '!=', '1' ),
					array( 'header-color', '=', 'header-color-custom' ),
				),
				'default'     => '#1F64FF',
				'mode'        => 'background',
				'transparent' => false,
			),

			array(
				'id'          => 'header_info_title_color',
				'type'        => 'color',
				'title'       => esc_html__( 'Info Title Color', 'medileaves' ),
				'required' => array(
					array( 'header_type', '!=', '1' ),
					array( 'header-color', '=', 'header-color-custom' ),
				),
				'default'     => '#000d44',
				'mode'        => 'background',
				'transparent' => false,
			),

			array(
				'id'          => 'header_info_content_color',
				'type'        => 'color',
				'title'       => esc_html__( 'Info Content Color', 'medileaves' ),
				'required' => array(
					array( 'header_type', '!=', '1' ),
					array( 'header-color', '=', 'header-color-custom' ),
				),
				'default'     => '#757575',
				'mode'        => 'background',
				'transparent' => false,
			),

			// Sticky Header Setting

			array(
				'id'     => 'header-sticky-section',
				'type'   => 'section',
				'title'  => esc_html__( 'Header Sticky', 'medileaves' ),
				'indent' => true,
			),

			array(
				'id'       => 'header_sticky',
				'type'     => 'button_set',
				'title'    => esc_html__( 'Header Sticky', 'medileaves' ),
				'subtitle' => esc_html__( 'Turn on to display enable the sticky header.', 'medileaves' ),
				'options'  => array(
					'on'  => esc_html__( 'On', 'medileaves' ),
					'off' => esc_html__( 'Off', 'medileaves' ),
				),
				'default'  => esc_html__( 'on', 'medileaves' ),
			),

			array(
				'id'     => 'header-search-section',
				'type'   => 'section',
				'title'  => esc_html__( 'Header Search', 'medileaves' ),
				'indent' => true,
			),


			array(
				'id'       => 'header_search',
				'type'     => 'button_set',
				'title'    => esc_html__( 'Header Search', 'medileaves' ),
				'subtitle' => esc_html__( 'Turn on to display the search Icon in top header.', 'medileaves' ),
				'options'  => array(
					'on'  => esc_html__( 'On', 'medileaves' ),
					'off' => esc_html__( 'Off', 'medileaves' ),
				),
				'default'  => esc_html__( 'on', 'medileaves' ),
			),

			array(
				'id'     => 'header-submenu-color',
				'type'   => 'section',
				'title'  => esc_html__( 'Submenu Color', 'medileaves' ),
				'indent' => true,
			),

			array(
				'id'       => 'submenu-color',
				'type'     => 'button_set',
				'title'    => __( 'Submenu Color Scheme', 'medileaves' ),
				'subtitle' => esc_html__( 'Choose Submenu Color Scheme.', 'medileaves' ),
				'options'  => array(
					'submenu-light' => 'Light',
					'submenu-dark' => 'Dark',
				),
				'default'  => 'submenu-light',
			),

			array(
				'id'     => 'header_custom_font',
				'type'   => 'section',
				'title'  => esc_html__( 'Menu Typography', 'medileaves' ),
				'indent' => true,
			),

			array(
				'id'       => 'nav-typography',
				'type'     => 'button_set',
				'title'    => __( 'Menu Typography', 'medileaves' ),
				'subtitle' => __( 'Specify the Main Navigation font properties.', 'medileaves' ),
				'required' => array( 'header_button', '=', 'on' ),
				'options'  => array(
					'1' => 'Default',
					'2' => 'Custom',
				),
				'default'  => '1',
			),

			array(
				'id'             => 'button-typography2',
				'type'           => 'typography',
				'title'          => __( 'Menu Font', 'medileaves' ),
				'subtitle'       => __( 'Specify the Header Menu font properties.', 'medileaves' ),
				'required'       => array( 'nav-typography', '=', '2' ),
				'google'         => true,
				'letter-spacing' => true,
				'font-backup'    => false,
				'text-transform' => true,
				'text-align'     => false,
				'color'          => false,
				'output'         => array( '.main-navigation .navbar-nav > li > a' ),
			),

		),
	)
);

Redux::setSection(
	'medileaves_redux',
	array(
		'title'            => esc_html__( 'Header Button', 'medileaves' ),
		'id'               => 'header-button',
		'subsection'       => true,
		'customizer_width' => '400px',
		'desc'             => esc_html__( 'This section contains options for header.', 'medileaves' ),
		'fields'           => array(

			array(
				'id'       => 'header_button',
				'type'     => 'button_set',
				'title'    => esc_html__( 'Header Button', 'medileaves' ),
				'subtitle' => esc_html__( 'Turn on to display the Header button in top header.', 'medileaves' ),
				'options'  => array(
					'on'  => esc_html__( 'On', 'medileaves' ),
					'off' => esc_html__( 'Off', 'medileaves' ),
				),
				'default'  => esc_html__( 'on', 'medileaves' ),
			),

			array(
				'id'       => 'header_btn_typography',
				'type'     => 'button_set',
				'title'    => __( 'Button Typography', 'medileaves' ),
				'subtitle' => __( 'Choose Header Button font properties.', 'medileaves' ),
				'required' => array( 'header_button', '=', 'on' ),
				'options'  => array(
					'1' => 'Default',
					'2' => 'Custom',
				),
				'default'  => '1',
			),

			array(
				'id'             => 'button-typography',
				'type'           => 'typography',
				'title'          => __( 'Button Font', 'medileaves' ),
				'subtitle'       => __( 'Specify the Header Button font properties.', 'medileaves' ),
				'required'       => array( 'header_btn_typography', '=', '2' ),
				'google'         => true,
				'letter-spacing' => true,
				'font-backup'    => false,
				'text-transform' => true,
				'text-align'     => false,
				'color'          => false,
			),

			array(
				'id'       => 'button_title',
				'type'     => 'text',
				'title'    => esc_html__( 'Button Text', 'medileaves' ),
				'subtitle' => __( 'Add Button text.', 'medileaves' ),
				'required' => array( 'header_button', '=', 'on' ),
				'default'  => 'Get Started',
				'desc'     => esc_html__( 'Change Title (e.g.Download).', 'medileaves' ),
			),

			array(
				'id'       => 'button_link',
				'type'     => 'text',
				'title'    => esc_html__( 'Button Link', 'medileaves' ),
				'subtitle' => __( 'Add Button link.', 'medileaves' ),
				'required' => array( 'header_button', '=', 'on' ),
				'desc'     => esc_html__( 'Add download link.', 'medileaves' ),
			),

			array(
				'id'       => 'button_style',
				'type'     => 'button_set',
				'title'    => __( 'Button Style', 'medileaves' ),
				'subtitle' => __( 'Select Button Style.', 'medileaves' ),
				'required' => array( 'header_button', '=', 'on' ),
				'options'  => array(
					'button-flat' => 'Flat',
					'button-border' => 'Border',
				),
				'default'  => 'button-flat',
				'desc'     => esc_html__( 'Button Style Option Not Working in Header Style 2.', 'medileaves' ),
			),

			array(
				'id'       => 'button_shap',
				'type'     => 'button_set',
				'title'    => __( 'Button Shap', 'medileaves' ),
				'subtitle' => __( 'Choose Button Shap.', 'medileaves' ),
				'required' => array( 'header_button', '=', 'on' ),
				'options'  => array(
					'button-square' => 'Square',
					'button-round' => 'Round',
					'button-rounded' => 'Rounded',
				),
				'default'  => 'button-square',
				'desc'     => esc_html__( 'Button Shap Option Not Working in Header Style 2.', 'medileaves' ),
			),

			array(
				'id'       => 'button_color',
				'type'     => 'button_set',
				'title'    => __( 'Button Color', 'medileaves' ),
				'subtitle' => __( 'Choose Button Color Scheme.', 'medileaves' ),
				'required' => array( 'header_button', '=', 'on' ),
				'options'  => array(
					'button-dark' => 'Dark',
					'button-light' => 'Light',
					'button-theme' => 'Primary',
					'button-gradient' => 'Gradient',
					'button-theme-second' => 'Primary Second',
				),
				'default'  => 'button-dark',
			),
		),
	)
);


// Redux::setSection(
// 	'medileaves_redux',
// 	array(
// 		'title'            => esc_html__( 'Header Sidemenu', 'medileaves' ),
// 		'id'               => 'header-sidemenu',
// 		'subsection'       => true,
// 		'customizer_width' => '400px',
// 		'desc'             => esc_html__( 'This section contains options for header.', 'medileaves' ),
// 		'fields'           => array(

// 			array(
// 				'id'       => 'header_sidemenu',
// 				'type'     => 'button_set',
// 				'title'    => esc_html__( 'Header Sidemenu', 'medileaves' ),
// 				'subtitle' => esc_html__( 'Turn on to display the Header button in top header.', 'medileaves' ),
// 				'options'  => array(
// 					'on'  => esc_html__( 'On', 'medileaves' ),
// 					'off' => esc_html__( 'Off', 'medileaves' ),
// 				),
// 				'default'  => esc_html__( 'on', 'medileaves' ),
// 			),
// 		),
// 	)
// );
